import * as i0 from '@angular/core';
import { Directive, Input, Component, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as qrCodeService from '@mintplayer/qr-code';

class QrCodeDirective {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
        //#region Version
        this.version = null;
        this.darkColor = '#000000FF';
        this.lightColor = '#FFFFFFFF';
        this.errorCorrectionLevel = QrCodeDirective.DEFAULT_ERROR_CORRECTION_LEVEL;
        this.margin = 16;
    }
    set qrCodeVersion(value) {
        if (value && (value > 40)) {
            this.version = 40;
        }
        else if (value && (value < 1)) {
            this.version = 1;
        }
        else {
            this.version = null;
        }
    }
    async ngOnChanges() {
        if (!this.value) {
            return;
        }
        const canvas = this.viewContainerRef.element.nativeElement;
        if (!canvas) {
            // native element not available on server side rendering
            return;
        }
        const context = canvas.getContext('2d');
        if (context) {
            context.clearRect(0, 0, context.canvas.width, context.canvas.height);
        }
        const errorCorrectionLevel = this.errorCorrectionLevel ?? QrCodeDirective.DEFAULT_ERROR_CORRECTION_LEVEL;
        const dark = !this.darkColor
            ? undefined
            : QrCodeDirective.VALID_COLOR_REGEX.test(this.darkColor)
                ? this.darkColor
                : undefined;
        const light = !this.lightColor
            ? undefined
            : QrCodeDirective.VALID_COLOR_REGEX.test(this.lightColor)
                ? this.lightColor
                : undefined;
        await qrCodeService
            .toCanvas(canvas, this.value, {
            version: this.version ?? undefined,
            errorCorrectionLevel,
            width: this.width,
            margin: this.margin,
            color: {
                dark,
                light,
            },
        });
        const centerImageSrc = this.centerImageSrc;
        const centerImageWidth = this.getIntOrDefault(this.centerImageWidth, QrCodeDirective.DEFAULT_CENTER_IMAGE_SIZE);
        const centerImageHeight = this.getIntOrDefault(this.centerImageHeight, QrCodeDirective.DEFAULT_CENTER_IMAGE_SIZE);
        if (centerImageSrc && context) {
            if (!this.centerImage) {
                this.centerImage = new Image(centerImageWidth, centerImageHeight);
            }
            if (centerImageSrc !== this.centerImage?.src) {
                this.centerImage.src = centerImageSrc;
            }
            if (centerImageWidth !== this.centerImage.width) {
                this.centerImage.width = centerImageWidth;
            }
            if (centerImageHeight !== this.centerImage.height) {
                this.centerImage.height = centerImageHeight;
            }
            const centerImage = this.centerImage;
            centerImage.onload = () => {
                context.drawImage(centerImage, canvas.width / 2 - centerImageWidth / 2, canvas.height / 2 - centerImageHeight / 2, centerImageWidth, centerImageHeight);
            };
        }
    }
    getIntOrDefault(value, defaultValue) {
        if (value === undefined || value === '') {
            return defaultValue;
        }
        else if (typeof value === 'string') {
            return parseInt(value, 10);
        }
        else {
            return value;
        }
    }
}
QrCodeDirective.VALID_COLOR_REGEX = /^#(?:[0-9a-fA-F]{3,4}){1,2}$/;
QrCodeDirective.DEFAULT_ERROR_CORRECTION_LEVEL = 'M';
QrCodeDirective.DEFAULT_CENTER_IMAGE_SIZE = 40;
QrCodeDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeDirective, deps: [{ token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive });
QrCodeDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.0", type: QrCodeDirective, selector: "canvas[qrCode]", inputs: { value: ["qrCode", "value"], qrCodeVersion: "qrCodeVersion", width: "width", height: "height", darkColor: "darkColor", lightColor: "lightColor", errorCorrectionLevel: ["qrCodeErrorCorrectionLevel", "errorCorrectionLevel"], centerImageSrc: ["qrCodeCenterImageSrc", "centerImageSrc"], centerImageWidth: ["qrCodeCenterImageWidth", "centerImageWidth"], centerImageHeight: ["qrCodeCenterImageHeight", "centerImageHeight"], margin: ["qrCodeMargin", "margin"] }, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'canvas[qrCode]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ViewContainerRef }]; }, propDecorators: { value: [{
                type: Input,
                args: ['qrCode']
            }], qrCodeVersion: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], darkColor: [{
                type: Input
            }], lightColor: [{
                type: Input
            }], errorCorrectionLevel: [{
                type: Input,
                args: ['qrCodeErrorCorrectionLevel']
            }], centerImageSrc: [{
                type: Input,
                args: ['qrCodeCenterImageSrc']
            }], centerImageWidth: [{
                type: Input,
                args: ['qrCodeCenterImageWidth']
            }], centerImageHeight: [{
                type: Input,
                args: ['qrCodeCenterImageHeight']
            }], margin: [{
                type: Input,
                args: ['qrCodeMargin']
            }] } });

class QrCodeComponent {
}
QrCodeComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
QrCodeComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.0", type: QrCodeComponent, selector: "qr-code", inputs: { value: "value", size: "size", darkColor: "darkColor", lightColor: "lightColor", errorCorrectionLevel: "errorCorrectionLevel", centerImageSrc: "centerImageSrc", centerImageSize: "centerImageSize", margin: "margin" }, ngImport: i0, template: "<canvas *ngIf=\"value\"\n    [qrCode]=\"value\"\n    [qrCodeErrorCorrectionLevel]=\"errorCorrectionLevel\"\n    [qrCodeCenterImageSrc]=\"centerImageSrc\"\n    [qrCodeCenterImageWidth]=\"centerImageSize\"\n    [qrCodeCenterImageHeight]=\"centerImageSize\"\n    [qrCodeMargin]=\"margin\"\n    [width]=\"size\"\n    [height]=\"size\"\n    [darkColor]=\"darkColor\"\n    [lightColor]=\"lightColor\">\n</canvas>\n", styles: [""], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: QrCodeDirective, selector: "canvas[qrCode]", inputs: ["qrCode", "qrCodeVersion", "width", "height", "darkColor", "lightColor", "qrCodeErrorCorrectionLevel", "qrCodeCenterImageSrc", "qrCodeCenterImageWidth", "qrCodeCenterImageHeight", "qrCodeMargin"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'qr-code', template: "<canvas *ngIf=\"value\"\n    [qrCode]=\"value\"\n    [qrCodeErrorCorrectionLevel]=\"errorCorrectionLevel\"\n    [qrCodeCenterImageSrc]=\"centerImageSrc\"\n    [qrCodeCenterImageWidth]=\"centerImageSize\"\n    [qrCodeCenterImageHeight]=\"centerImageSize\"\n    [qrCodeMargin]=\"margin\"\n    [width]=\"size\"\n    [height]=\"size\"\n    [darkColor]=\"darkColor\"\n    [lightColor]=\"lightColor\">\n</canvas>\n" }]
        }], propDecorators: { value: [{
                type: Input
            }], size: [{
                type: Input
            }], darkColor: [{
                type: Input
            }], lightColor: [{
                type: Input
            }], errorCorrectionLevel: [{
                type: Input
            }], centerImageSrc: [{
                type: Input
            }], centerImageSize: [{
                type: Input
            }], margin: [{
                type: Input
            }] } });

class QrCodeModule {
}
QrCodeModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
QrCodeModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.0", ngImport: i0, type: QrCodeModule, declarations: [QrCodeComponent,
        QrCodeDirective], imports: [CommonModule], exports: [QrCodeComponent,
        QrCodeDirective] });
QrCodeModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: QrCodeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [
                        QrCodeComponent,
                        QrCodeDirective
                    ],
                    exports: [
                        QrCodeComponent,
                        QrCodeDirective
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { QrCodeComponent, QrCodeDirective, QrCodeModule };
//# sourceMappingURL=mintplayer-ng-qr-code.mjs.map
